@@ -541,7 +541,7 @@ def collect_object(client, param_object, view, args, wait_thread=None,
                 if wait_thread:
                     wait_thread.pause()
                 label = field.label or _("Password")
-                password=get_password("%s: "%label,
+                password=get_password(label+_(": "),
                                       _('Repeat password: '),
                                       getfromstdin=stdin_passwd,
                                       needrepeat=not "one" in field.type)
@@ -590,6 +590,11 @@ def convertArgDictToList(argDict):
 
 def collect_table(field, val_list, client, wait_thread = None,
                   stdin_passwd = False):
+    def split_param(l, delimeter=","):
+        for x in l:
+            for y in x.split(','):
+                yield y
+
     if not val_list:
         return None
     # if specified syntax for table row
@@ -610,7 +615,8 @@ def collect_table(field, val_list, client, wait_thread = None,
         val_table = list(convertArgDictToList(argDict))
     # standard syntax
     else:
-        val_table = map(lambda x: x.split(':'), val_list)
+        reduced_list = list(split_param(val_list))
+        val_table = map(lambda x: x.split(':'), reduced_list)
 
     if type(field.tablevalue.values) in [list, tuple]:
         choiceValue = field.tablevalue.values
